@@ -3,11 +3,11 @@ import os
 import platform
 import logging
 
-from serverless_sdk.lib.trace import TraceSpan
+from sls_sdk.lib.trace import TraceSpan
+from sls_sdk.lib.timing import _DIFF
 
 __all__ = [
     "aws_lambda_span",
-    "reset",
 ]
 
 
@@ -40,7 +40,7 @@ if arch:
 
 aws_lambda_span = TraceSpan(
     "aws.lambda",
-    start_time=int(os.environ.get("_SLS_PROCESS_START_TIME", 0)),
+    start_time=int(os.environ.get("_SLS_PROCESS_START_TIME", 0)) - _DIFF,
     immediate_descendants=["aws.lambda.initialization"],
     tags=IMMUTABLE_TAGS,
 )
@@ -49,7 +49,10 @@ if os.environ.get("AWS_LAMBDA_INITIALIZATION_TYPE") == "on-demand":
     aws_lambda_span.tags["aws.lambda.is_coldstart"] = True
 
 
-def reset():
-    aws_lambda_span.tags.clear()
-    aws_lambda_span.tags.update(IMMUTABLE_TAGS)
-    aws_lambda_span.sub_spans.clear()
+def _clear(self: TraceSpan):
+    self.tags.clear()
+    self.tags.update(IMMUTABLE_TAGS)
+    self.sub_spans.clear()
+
+
+TraceSpan.clear = _clear
